# ***********Object Detection code******************
#
# inspired by Simon Monk, Raspberry Pi Cookbook, 2013
#
# modified by Don Wilcher Dec 18, 2015
#
# Placing a object over the photocell will turn on the dc motor. 
# Placing an object over the photocell a 2nd time turns off the motor.

# Add libraries to python script

import RPi.GPIO as GPIO
import time

# Include BCM I/O pins into python script and define pin numbers

GPIO.setmode(GPIO.BCM)
photocell_pin = 4
motor_pin = 18

# Create photocell pin as an active low switch (use RPi internal pullup resistor)
# and define motor pin as an output.

GPIO.setup(photocell_pin, GPIO.IN, pull_up_down = GPIO.PUD_UP)
GPIO.setup(motor_pin, GPIO.OUT)

# Define and set (initialize) the motor output state as False and the old input event as True

motor_state = False
old_input_event = True

# pbswitch event monitoring loop: check pbswitch_pin and toggle dc motor  output based on input events
# being True or False
while True:
    new_input_event = GPIO.input(photocell_pin)
    if new_input_event == False and old_input_event == True:
        motor_state = not motor_state
    old_input_event = new_input_event
    GPIO.output(motor_pin, motor_state)
    time.sleep(0.1)#provides a 100 msec motor actuation on/off time
    

